@@ -46,14 +46,8 @@ class KPIEvaluationEndpointConfig(EndpointViewConfig):
 
 
 class EvaluationGraphEndpointConfig(EndpointViewConfig):
-    def get_list_endpoint(self, **kwargs):
-        return reverse(
-            "wbhuman_resources:kpi-evaluationgraph-list",
-            args=[self.view.kwargs["kpi_id"]],
-            request=self.request,
-        )
+    pass
 
 
 class KPIEvaluationPandasEndpointConfig(EndpointViewConfig):
-    def get_list_endpoint(self, **kwargs):
-        return reverse("wbhuman_resources:kpievaluationpandas-list", [], request=self.request)
+    pass
